# History

## 0.1.3 (2023-03-13)

-   Update documentation to include sponsor links, and complete install instructions.

## 0.1.2 (2023-03-09)

-   Embed images in documentation.
-   Convert `.rst` files to `.md` format.

## 0.1.1 (2023-03-08)

-   Update documentation.

## 0.1.0 (2023-03-08)

-   First release on PyPI.
